summaryrefslogtreecommitdiffstats
path: root/src/input_common/sdl/sdl_impl.h
diff options
context:
space:
mode:
authorJames Rowe <jroweboy@gmail.com>2018-09-20 08:28:05 +0200
committerfearlessTobi <thm.frey@gmail.com>2019-03-02 19:09:34 +0100
commit09ac66388c01187ed6a402efcad76984c8af9a2e (patch)
treebeed8a86e7b7e02e0c5526723bbf812920341d12 /src/input_common/sdl/sdl_impl.h
parentInput: Copy current SDL.h/cpp files to impl (diff)
downloadyuzu-09ac66388c01187ed6a402efcad76984c8af9a2e.tar
yuzu-09ac66388c01187ed6a402efcad76984c8af9a2e.tar.gz
yuzu-09ac66388c01187ed6a402efcad76984c8af9a2e.tar.bz2
yuzu-09ac66388c01187ed6a402efcad76984c8af9a2e.tar.lz
yuzu-09ac66388c01187ed6a402efcad76984c8af9a2e.tar.xz
yuzu-09ac66388c01187ed6a402efcad76984c8af9a2e.tar.zst
yuzu-09ac66388c01187ed6a402efcad76984c8af9a2e.zip
Diffstat (limited to '')
-rw-r--r--src/input_common/sdl/sdl_impl.h79
1 files changed, 46 insertions, 33 deletions
diff --git a/src/input_common/sdl/sdl_impl.h b/src/input_common/sdl/sdl_impl.h
index c152fa747..fec82fbe6 100644
--- a/src/input_common/sdl/sdl_impl.h
+++ b/src/input_common/sdl/sdl_impl.h
@@ -1,51 +1,64 @@
-// Copyright 2017 Citra Emulator Project
+// Copyright 2018 Citra Emulator Project
// Licensed under GPLv2 or any later version
// Refer to the license.txt file included.
#pragma once
+#include <atomic>
#include <memory>
-#include <vector>
-#include "core/frontend/input.h"
+#include <thread>
+#include "common/threadsafe_queue.h"
+#include "input_common/sdl/sdl.h"
union SDL_Event;
-namespace Common {
-class ParamPackage;
-}
-namespace InputCommon {
-namespace Polling {
-class DevicePoller;
-enum class DeviceType;
-} // namespace Polling
-} // namespace InputCommon
+using SDL_Joystick = struct _SDL_Joystick;
+using SDL_JoystickID = s32;
-namespace InputCommon {
-namespace SDL {
+namespace InputCommon::SDL {
-/// Initializes and registers SDL device factories
-void Init();
+class SDLJoystick;
+class SDLButtonFactory;
+class SDLAnalogFactory;
-/// Unresisters SDL device factories and shut them down.
-void Shutdown();
+class SDLState : public State {
+public:
+ /// Initializes and registers SDL device factories
+ SDLState();
-/// Needs to be called before SDL_QuitSubSystem.
-void CloseSDLJoysticks();
+ /// Unresisters SDL device factories and shut them down.
+ ~SDLState() override;
-/// Handle SDL_Events for joysticks from SDL_PollEvent
-void HandleGameControllerEvent(const SDL_Event& event);
+ /// Handle SDL_Events for joysticks from SDL_PollEvent
+ void HandleGameControllerEvent(const SDL_Event& event);
-/// A Loop that calls HandleGameControllerEvent until Shutdown is called
-void PollLoop();
+ std::shared_ptr<SDLJoystick> GetSDLJoystickBySDLID(SDL_JoystickID sdl_id);
+ std::shared_ptr<SDLJoystick> GetSDLJoystickByGUID(const std::string& guid, int port);
-/// Creates a ParamPackage from an SDL_Event that can directly be used to create a ButtonDevice
-Common::ParamPackage SDLEventToButtonParamPackage(const SDL_Event& event);
+ /// Get all DevicePoller that use the SDL backend for a specific device type
+ std::vector<std::unique_ptr<InputCommon::Polling::DevicePoller>> GetPollers(
+ InputCommon::Polling::DeviceType type) override;
-namespace Polling {
+ /// Used by the Pollers during config
+ std::atomic<bool> polling = false;
+ Common::SPSCQueue<SDL_Event> event_queue;
-/// Get all DevicePoller that use the SDL backend for a specific device type
-void GetPollers(InputCommon::Polling::DeviceType type,
- std::vector<std::unique_ptr<InputCommon::Polling::DevicePoller>>& pollers);
+private:
+ void InitJoystick(int joystick_index);
+ void CloseJoystick(SDL_Joystick* sdl_joystick);
-} // namespace Polling
-} // namespace SDL
-} // namespace InputCommon
+ /// Needs to be called before SDL_QuitSubSystem.
+ void CloseJoysticks();
+
+ /// Map of GUID of a list of corresponding virtual Joysticks
+ std::unordered_map<std::string, std::vector<std::shared_ptr<SDLJoystick>>> joystick_map;
+ std::mutex joystick_map_mutex;
+
+ std::shared_ptr<SDLButtonFactory> button_factory;
+ std::shared_ptr<SDLAnalogFactory> analog_factory;
+
+ bool start_thread = false;
+ std::atomic<bool> initialized = false;
+
+ std::thread poll_thread;
+};
+} // namespace InputCommon::SDL